# SRMASV Protobuf Library
------
This repository contains the SRMASV protobuf library.
------
## To install just run the following:
`python setup.py install`

The following module contains the following messages implemented in Google Protobuf:

#### asvprotobuf.std
-----
- [x] Header
- [x] Orientation
- [x] Vector

#### asvprotobuf.sensor
-----
- [x] Imu
- [x] GPSFix
- [x] Image
- [x] LaserScan

#### asvprotobuf.diagnostics
-----
- TODO
